"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const socket_server_1 = __importDefault(require("./socket_server"));
/**
 * All MQL5 Account Info can be found on this static class
 *
 * @example
 * //Request the login id of account from MT5
 * console.log(AccountInfo.loginId())
 *
 */
class AccountInfo {
    /**
     * In AccountInfo all request are same. So, a get() method
     * created for request data
     * @param event_name request AccountInfo using event_name
     */
    static get(event_name) {
        return __awaiter(this, void 0, void 0, function* () {
            socket_server_1.default.getInstance().send(JSON.stringify({ event: event_name }));
            let data = JSON.parse(yield socket_server_1.default.getInstance().receive());
            if (Object.keys(data).includes(event_name)) {
                return data[event_name];
            }
            return null;
        });
    }
    /**
     * Account number
     */
    static loginId() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.get("login_id");
        });
    }
    /**
     * Account trade mode
     */
    static tradeMode() {
        return __awaiter(this, void 0, void 0, function* () {
            let res = yield this.get("trade_mode");
            return res;
        });
    }
    /**
     * Account leverage
     */
    static leverage() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("leverage");
        });
    }
    /**
     * Maximum allowed number of active pending orders
     */
    static maxOrdersLimit() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("limit_orders");
        });
    }
    /**
     * Mode for setting the minimal allowed margin
     */
    static stopoutMode() {
        return __awaiter(this, void 0, void 0, function* () {
            let res = yield this.get("stopout_mode");
            return res;
        });
    }
    /**
     * Allowed trade for the current account
     */
    static isTradeAllowed() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("is_trade_allowed");
        });
    }
    /**
     * Allowed trade for an Expert Advisor
     */
    static canExpertTrade() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("can_expert_trade");
        });
    }
    /**
     * Margin calculation mode
     */
    static marginMode() {
        return __awaiter(this, void 0, void 0, function* () {
            return (yield this.get("margin_mode"));
        });
    }
    /**
     * The number of decimal places in the account currency,
     * which are required for an accurate display of trading results
     */
    static currencyDigit() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("account_currency_digit");
        });
    }
    /**
     * Account balance in the deposit currency
     */
    static balance() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("balance");
        });
    }
    /**
     * Account credit in the deposit currency
     */
    static credit() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("credit");
        });
    }
    /**
     * Current profit of an account in the deposit currency
     */
    static profit() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("profit");
        });
    }
    /**
     * Account equity in the deposit currency
     */
    static equity() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("equity");
        });
    }
    /**
     * Account margin used in the deposit currency
     */
    static margin() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("margin");
        });
    }
    /**
     * Free margin of an account in the deposit currency
     */
    static marginFree() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("margin_free");
        });
    }
    /**
     * Account margin level in percents
     */
    static marginLevel() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("margin_level");
        });
    }
    /**
     * Margin call level. Depending on the set ACCOUNT_MARGIN_SO_MODE is expressed in percents or in the deposit currency
     */
    static marginSoCall() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("margin_so_call");
        });
    }
    /**
     * Margin stop out level. Depending on the set ACCOUNT_MARGIN_SO_MODE is expressed in percents or in the deposit currency
     */
    static marginSoSo() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("margin_so_so");
        });
    }
    /**
     * Maintenance margin. The minimum equity reserved on an account to cover the minimum amount of all open positions
     */
    static marginMaintenance() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("margin_maintenance");
        });
    }
    /**
     * The current assets of an account
     */
    static assets() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("assets");
        });
    }
    /**
     * The current liabilities on an account
     */
    static liabilities() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("liabilities");
        });
    }
    /**
     * The current blocked commission amount on an account
     */
    static commisionBlocked() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("commision_blocked");
        });
    }
    /**
     * Client name
     */
    static accountName() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("account_name");
        });
    }
    /**
     * Trade server name
     */
    static Server() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("account_server");
        });
    }
    /**
     * Account currency
     */
    static currency() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("account_currency");
        });
    }
    /**
     * Name of a company that serves the account
     */
    static company() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.get("account_company");
        });
    }
}
exports.AccountInfo = AccountInfo;
var AccountTradeMode;
(function (AccountTradeMode) {
    AccountTradeMode[AccountTradeMode["DEMO"] = 0] = "DEMO";
    AccountTradeMode[AccountTradeMode["REAL"] = 1] = "REAL";
    AccountTradeMode[AccountTradeMode["CONTEST"] = 2] = "CONTEST";
})(AccountTradeMode = exports.AccountTradeMode || (exports.AccountTradeMode = {}));
var AccountStopoutMode;
(function (AccountStopoutMode) {
    AccountStopoutMode[AccountStopoutMode["MONEY"] = 0] = "MONEY";
    AccountStopoutMode[AccountStopoutMode["PERCENT"] = 1] = "PERCENT";
})(AccountStopoutMode = exports.AccountStopoutMode || (exports.AccountStopoutMode = {}));
var AccountMarginMode;
(function (AccountMarginMode) {
    AccountMarginMode[AccountMarginMode["RETAIL_NETTING"] = 0] = "RETAIL_NETTING";
    AccountMarginMode[AccountMarginMode["RETAIL_HEDGING"] = 1] = "RETAIL_HEDGING";
    AccountMarginMode[AccountMarginMode["EXCHANGE"] = 2] = "EXCHANGE";
})(AccountMarginMode = exports.AccountMarginMode || (exports.AccountMarginMode = {}));
