"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const socket_server_1 = __importDefault(require("./socket_server"));
/**
 *
 */
class Event {
    selectSymbol(symbol_name) {
        this.symbol = symbol_name;
        return this;
    }
    /**
     * @param from_date this date can be used by retrieving bar_history
     * @returns Event is returned for build data flow for bar_history
     */
    fromDate(from_date) {
        this.from_date = from_date;
        return this;
    }
    /**
     * @param to_date this date can be used by retrieving bar_history
     * @returns Event is returned for build data flow for bar_history
     */
    toDate(to_date) {
        this.to_date = to_date;
        return this;
    }
    /**
     * @param timeframe Needs when onBar is called
     * @returns Event is returned for build data flow for onBarEvent
     */
    timeframe(timeframe) {
        this._timeframe = timeframe;
        return this;
    }
    /**
     *
     * @param history_bar_count When onBar event called this amount of bars will send to onBar event callbacks
     */
    historyBarCount(history_bar_count) {
        this._historyBarCount = history_bar_count;
        return this;
    }
    /**
     *
     * @param history_tick_count when onTick event called this amount of ticks will send to onTick event callbacks
     */
    historyTickCount(history_tick_count) {
        this._historyTickCount = history_tick_count;
        return this;
    }
    /**
     * Convert Javascript date to Mql5 date
     * @param date JavaScript date
     */
    jsDateToMqlDate(date) {
        return (date.getFullYear() +
            "." +
            ((date.getMonth() < 10 ? "0" : "") + (date.getMonth() + 1)) +
            "." +
            ((date.getDate() < 10 ? "0" : "") + date.getDate()) +
            " " +
            ((date.getHours() < 10 ? "0" : "") + date.getHours()) +
            ":" +
            ((date.getMinutes() < 10 ? "0" : "") + date.getMinutes()) +
            ":00");
    }
    /**
     * Get price history bars - requires
     *    1. symbol name
     *    2. timeframe
     *    3. from date
     *    4. to date
     */
    getBars() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.symbol == undefined || this.symbol == null) {
                throw new Error("selectSymbol is undefined or null");
            }
            if (this._timeframe == undefined || this._timeframe == null) {
                throw new Error("timeframe is undefined or null");
            }
            if (this.from_date == undefined || this.from_date == null) {
                throw new Error("fromDate is undefined or null");
            }
            if (this.to_date == undefined || this.to_date == null) {
                throw new Error("toDate is undefined or null");
            }
            let from_date = new Date(this.from_date);
            let to_date = new Date(this.from_date);
            to_date.setDate(from_date.getDate() + 22);
            if (to_date > this.to_date) {
                to_date = new Date(this.to_date);
            }
            let bar_data = [];
            while (true) {
                let send_data = JSON.stringify({
                    event: "bar_history",
                    symbol_name: this.symbol,
                    timeframe: this._timeframe,
                    from_date: this.jsDateToMqlDate(from_date),
                    to_date: this.jsDateToMqlDate(to_date)
                });
                socket_server_1.default.getInstance().send(send_data);
                let result = JSON.parse(yield socket_server_1.default.getInstance().receive());
                if (Object.keys(result).includes("bar_history") &&
                    result.bar_history != null) {
                    let tmp_data = result.bar_history;
                    tmp_data.forEach((bar) => {
                        bar_data.push(bar);
                    });
                }
                if (to_date >= this.to_date) {
                    break;
                }
                from_date = new Date(to_date);
                to_date.setDate(from_date.getDate() + 22);
                if (to_date > this.to_date) {
                    to_date = this.to_date;
                }
            }
            return bar_data;
        });
    }
    /**
     * onBar event called when a new bar is formed using your specified parameters - requires
     *    1. symbol name
     *    2. timeframe
     *    3. history bar count
     * @param on_bar_callback when a new bar is formed this callback will be called with amount of history bars you specified
     */
    onBar(on_bar_callback) {
        socket_server_1.default.getInstance().send(JSON.stringify({
            event: "bar_event_sub",
            symbol_name: this.symbol,
            timeframe: this._timeframe,
            history_count: this._historyBarCount
        }));
        let event_name = this.symbol + "_" + this._timeframe + "_" + this._historyBarCount;
        socket_server_1.default.getInstance().subscribe(event_name);
        socket_server_1.default.getInstance().onEvent(event_name, (datas) => {
            let bars_res = JSON.parse(datas)[event_name];
            on_bar_callback(bars_res);
        });
        return this;
    }
    /**
     * onTick event will called when a new tick is found - requires
     *    1. symbol name
     *    2. history tick count
     * @param on_tick_callback when a new tick is found this callback will be called with amount of tick history you specified
     */
    onTick(on_tick_callback) {
        socket_server_1.default.getInstance().send(JSON.stringify({
            event: "tick_event_sub",
            symbol_name: this.symbol,
            history_count: this._historyTickCount
        }));
        let event_name = this.symbol + "_" + this._historyTickCount;
        socket_server_1.default.getInstance().subscribe(event_name);
        socket_server_1.default.getInstance().onEvent(event_name, (datas) => {
            let ticks_res = JSON.parse(datas)[event_name];
            on_tick_callback(ticks_res);
        });
        return this;
    }
    /**
     * If onBar event is not needed anymore than unsubscribe it
     */
    unsubscribeOnBarEvent() {
        socket_server_1.default.getInstance().send(JSON.stringify({
            event: "bar_event_unsub",
            symbol_name: this.symbol,
            timeframe: this._timeframe,
            history_count: this._historyBarCount
        }));
        socket_server_1.default.getInstance().unsubscribe(this.symbol + "_" + this._timeframe + "_" + this._historyBarCount);
    }
    /**
     * If onTick event is not needed anymore than unsubsribe it
     */
    unsubscribeOnTickEvent() {
        socket_server_1.default.getInstance().send(JSON.stringify({
            event: "ticket_event_unsub",
            symbol_name: this.symbol,
            history_count: this._historyTickCount
        }));
        socket_server_1.default.getInstance().unsubscribe(this.symbol + "_" + this._historyTickCount);
    }
}
exports.Event = Event;
var Timeframe;
(function (Timeframe) {
    Timeframe["M1"] = "M1";
    Timeframe["M2"] = "M2";
    Timeframe["M3"] = "M3";
    Timeframe["M4"] = "M4";
    Timeframe["M5"] = "M5";
    Timeframe["M6"] = "M6";
    Timeframe["M10"] = "M10";
    Timeframe["M12"] = "M12";
    Timeframe["M15"] = "M15";
    Timeframe["M20"] = "M20";
    Timeframe["M30"] = "M30";
    Timeframe["H1"] = "H1";
    Timeframe["H2"] = "H2";
    Timeframe["H3"] = "H3";
    Timeframe["H4"] = "H4";
    Timeframe["H6"] = "H6";
    Timeframe["H8"] = "H8";
    Timeframe["H12"] = "H12";
    Timeframe["D1"] = "D1";
    Timeframe["W1"] = "W1";
    Timeframe["MN1"] = "MN1";
})(Timeframe = exports.Timeframe || (exports.Timeframe = {}));
var TickFlag;
(function (TickFlag) {
    TickFlag["ASK"] = "ASK";
    TickFlag["BID"] = "BID";
    TickFlag["BUY"] = "BUY";
    TickFlag["SELL"] = "SELL";
    TickFlag["LAST"] = "LAST";
    TickFlag["VOLUME"] = "VOLUME";
    TickFlag["NONE"] = "NONE";
})(TickFlag = exports.TickFlag || (exports.TickFlag = {}));
