"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const zeromq_1 = require("zeromq");
class SocketServer {
    constructor(protocol, hostname, push_port, pull_port, sub_port, timeout_ms) {
        this.pushAddress = "";
        this.pullAddress = "";
        this.subAddress = "";
        this.pushSocket = zeromq_1.socket("push");
        this.pullSocket = zeromq_1.socket("pull");
        this.subSocket = zeromq_1.socket("sub");
        this.connected = false;
        this.msg = "";
        this.timeout_ms = 1000;
        this.event_callbacks = new Map();
        this.pushAddress = protocol + "://" + hostname + ":" + push_port;
        this.pullAddress = protocol + "://" + hostname + ":" + pull_port;
        this.subAddress = protocol + "://" + hostname + ":" + sub_port;
        this.timeout_ms = timeout_ms;
    }
    static getInstance(protocol = "tcp", hostname = "127.0.0.1", push_port = 3033, pull_port = 3034, sub_port = 3035, timeout_ms = 1000) {
        if (this.instance == null) {
            SocketServer.instance = new SocketServer(protocol, hostname, push_port, pull_port, sub_port, timeout_ms);
        }
        return this.instance;
    }
    connect() {
        this.pushSocket.connect(this.pushAddress);
        this.pullSocket.connect(this.pullAddress);
        this.subSocket.connect(this.subAddress);
        this.connected = true;
        this.pullSocket.on("message", (msg) => {
            this.msg = msg.toString();
        });
        this.subSocket.on("message", (data) => {
            let event_name = data.toString().substring(0, data.indexOf(" "));
            let datas = data.toString().substring(event_name.length + 1, data.length);
            if (this.event_callbacks.has(event_name)) {
                this.event_callbacks.get(event_name)(datas);
            }
        });
    }
    send(msg) {
        this.pushSocket.send(msg);
    }
    subscribe(event_name) {
        this.subSocket.subscribe(event_name);
    }
    unsubscribe(event_name) {
        this.subSocket.unsubscribe(event_name);
        if (this.event_callbacks.has(event_name)) {
            this.event_callbacks.delete(event_name);
        }
    }
    onEvent(event_name, listener) {
        this.event_callbacks.set(event_name, listener);
    }
    receive() {
        let start_time_ms = Date.now();
        return new Promise((resolve, reject) => {
            let interval = setInterval(() => {
                if (this.msg.length > 0) {
                    resolve(this.msg);
                    this.msg = "";
                    clearInterval(interval);
                }
                if (Date.now() >= start_time_ms + this.timeout_ms) {
                    resolve("{}");
                    this.msg = "";
                    clearInterval(interval);
                }
            }, 1);
        });
    }
    isConnected() {
        return this.connected;
    }
}
exports.default = SocketServer;
