"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const socket_server_1 = __importDefault(require("./socket_server"));
class SymbolInfo {
    /**
     *
     * @param event_name request for data to retrieve
     * @param symbol_name request particular symbol info
     */
    static get(event_name, symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            socket_server_1.default.getInstance().send(JSON.stringify({ event: event_name, symbol_name: symbol_name }));
            let data = JSON.parse(yield socket_server_1.default.getInstance().receive());
            if (Object.keys(data).includes(event_name) &&
                data.symbol_name == symbol_name) {
                return data[event_name];
            }
            return null;
        });
    }
    /**
     * List all symbols that available on your broker
     */
    static symbolList() {
        return __awaiter(this, void 0, void 0, function* () {
            socket_server_1.default.getInstance().send(JSON.stringify({ event: "symbol_list" }));
            let data = JSON.parse(yield socket_server_1.default.getInstance().receive());
            if (Object.keys(data).includes("symbol_list")) {
                return data.symbol_list;
            }
            return [];
        });
    }
    /**
     * Number of deals in the current session
     * @param symbol_name Retrieve specific symbol information
     */
    static sessionDeals(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("sess_deals", symbol_name);
            return data == null ? 0 : data;
        });
    }
    /**
     * Number of Buy orders at the moment
     * @param symbol_name Retrieve specific symbol information
     */
    static sessionBuyOrders(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("sess_buy_orders", symbol_name);
            return data == null ? 0 : data;
        });
    }
    /**
     * Number of Sell orders at the moment
     * @param symbol_name Retrieve specific symbol information
     */
    static sessionSellOrders(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("sess_sell_orders", symbol_name);
            return data == null ? 0 : data;
        });
    }
    /**
     * Volume of the last deal
     * @param symbol_name Retrieve specific symbol information
     */
    static volume(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("volume", symbol_name);
            return data == null ? 0 : data;
        });
    }
    /**
     * Maximal day volume
     * @param symbol_name Retrieve specific symbol information
     */
    static volumeHigh(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("volume_high", symbol_name);
            return data == null ? 0 : data;
        });
    }
    /**
     * Minimal day volume
     * @param symbol_name Retrieve specific symbol information
     */
    static volumeLow(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("volume_low", symbol_name);
            return data == null ? 0 : data;
        });
    }
    /**
     * Time of the last quote
     * @param symbol_name Retrieve specific symbol information
     */
    static time(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("time", symbol_name);
            return data == null ? "" : data;
        });
    }
    /**
     * Digits after a decimal point
     * @param symbol_name Retrieve specific symbol information
     */
    static digits(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("digits", symbol_name);
            return data == null ? 0 : data;
        });
    }
    /**
     * Indication of a floating spread
     * @param symbol_name Retrieve specific symbol information
     */
    static isSpreadFloat(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("is_spread_float", symbol_name);
            return data == null ? false : data;
        });
    }
    /**
     * Spread value in points
     * @param symbol_name Retrieve specific symbol information
     */
    static spread(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("spread", symbol_name);
            return data == null ? 0 : data;
        });
    }
    /**
     * Maximal number of requests shown in Depth of Market.
     *  For symbols that have no queue of requests, the value is equal to zero.
     * @param symbol_name Retrieve specific symbol information
     */
    static tickBookdepth(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("tick_bookdepth", symbol_name);
            return data == null ? 0 : data;
        });
    }
    /**
     * Order execution type
     * @param symbol_name Retrieve specific symbol information
     */
    static tradeMode(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("symbol_trade_mode", symbol_name);
            return data == null ? SymbolTradeMode.DISABLED : data;
        });
    }
    /**
     * Minimal indention in points from the current close price to place Stop orders
     * @param symbol_name Retrieve specific symbol information
     */
    static stopsLevel(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("trade_stops_level", symbol_name);
            return data == null ? 0 : data;
        });
    }
    /**
     * Distance to freeze trade operations in points
     * @param symbol_name Retrieve specific symbol information
     */
    static freezeLevel(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("trade_freeze_level", symbol_name);
            return data == null ? 0 : data;
        });
    }
    /**
     * Deal execution mode
     * @param symbol_name Retrieve specific symbol information
     */
    static tradeExecMode(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("trade_exec_mode", symbol_name);
            return data;
        });
    }
    /**
     * Swap calculation model
     * @param symbol_name Retrieve specific symbol information
     */
    static swapMode(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("swap_mode", symbol_name);
            return data;
        });
    }
    /**
     * Ask - best buy offer
     * @param symbol_name Retrieve specific symbol information
     */
    static ask(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("ask", symbol_name);
            return data;
        });
    }
    /**
     * Bid - best sell offer
     * @param symbol_name Retrieve specific symbol information
     */
    static bid(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("bid", symbol_name);
            return data;
        });
    }
    /**
     * Symbol point value
     * @param symbol_name Retrieve specific symbol information
     */
    static point(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("point", symbol_name);
            return data;
        });
    }
    /**
     * Maximal volume for a deal
     * @param symbol_name Retrieve specific symbol information
     */
    static volumeMax(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("vol_max", symbol_name);
            return data;
        });
    }
    /**
     * Minimal volume for a deal
     * @param symbol_name Retrieve specific symbol information
     */
    static volumeMin(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("vol_min", symbol_name);
            return data;
        });
    }
    /**
     * Minimal volume change step for deal execution
     * @param symbol_name Retrieve specific symbol information
     */
    static volumeStep(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("vol_step", symbol_name);
            return data;
        });
    }
    /**
     * Long swap value
     * @param symbol_name Retrieve specific symbol information
     */
    static swapLong(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("swap_long", symbol_name);
            return data;
        });
    }
    /**
     * Short swap value
     * @param symbol_name Retrieve specific symbol information
     */
    static swapShort(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("swap_short", symbol_name);
            return data;
        });
    }
    /**
     * Basic currency of a symbol
     * @param symbol_name Retrieve specific symbol information
     */
    static currencyBase(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("currency_base", symbol_name);
            return data;
        });
    }
    /**
     * Profit currency
     * @param symbol_name Retrieve specific symbol information
     */
    static currencyQuote(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("currency_quote", symbol_name);
            return data;
        });
    }
    /**
     * Margin currency
     * @param symbol_name Retrieve specific symbol information
     */
    static currencyMargin(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("currency_margin", symbol_name);
            return data;
        });
    }
    /**
     * Feeder of the current quote
     * @param symbol_name Retrieve specific symbol information
     */
    static broker(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("broker", symbol_name);
            return data;
        });
    }
    /**
     * Symbol description
     * @param symbol_name Retrieve specific symbol information
     */
    static description(symbol_name) {
        return __awaiter(this, void 0, void 0, function* () {
            let data = yield this.get("description", symbol_name);
            return data;
        });
    }
}
exports.SymbolInfo = SymbolInfo;
var SymbolTradeMode;
(function (SymbolTradeMode) {
    SymbolTradeMode[SymbolTradeMode["FULL"] = 0] = "FULL";
    SymbolTradeMode[SymbolTradeMode["LONG_ONLY"] = 1] = "LONG_ONLY";
    SymbolTradeMode[SymbolTradeMode["SHORT_ONLY"] = 2] = "SHORT_ONLY";
    SymbolTradeMode[SymbolTradeMode["CLOSE_ONLY"] = 3] = "CLOSE_ONLY";
    SymbolTradeMode[SymbolTradeMode["DISABLED"] = 4] = "DISABLED";
})(SymbolTradeMode = exports.SymbolTradeMode || (exports.SymbolTradeMode = {}));
var SymbolTradeExecMode;
(function (SymbolTradeExecMode) {
    SymbolTradeExecMode[SymbolTradeExecMode["REQUEST"] = 0] = "REQUEST";
    SymbolTradeExecMode[SymbolTradeExecMode["INSTANT"] = 1] = "INSTANT";
    SymbolTradeExecMode[SymbolTradeExecMode["MARKET"] = 2] = "MARKET";
    SymbolTradeExecMode[SymbolTradeExecMode["EXCHANGE"] = 3] = "EXCHANGE";
})(SymbolTradeExecMode = exports.SymbolTradeExecMode || (exports.SymbolTradeExecMode = {}));
var SymbolSwapMode;
(function (SymbolSwapMode) {
    SymbolSwapMode[SymbolSwapMode["CURRENCY_DEPOSIT"] = 0] = "CURRENCY_DEPOSIT";
    SymbolSwapMode[SymbolSwapMode["CURRENCY_MARGIN"] = 1] = "CURRENCY_MARGIN";
    SymbolSwapMode[SymbolSwapMode["CURRENCY_SYMBOL"] = 2] = "CURRENCY_SYMBOL";
    SymbolSwapMode[SymbolSwapMode["INTEREST_CURRENT"] = 3] = "INTEREST_CURRENT";
    SymbolSwapMode[SymbolSwapMode["INTEREST_OPEN"] = 4] = "INTEREST_OPEN";
    SymbolSwapMode[SymbolSwapMode["POINTS"] = 5] = "POINTS";
    SymbolSwapMode[SymbolSwapMode["REOPEN_BID"] = 6] = "REOPEN_BID";
    SymbolSwapMode[SymbolSwapMode["REOPEN_CURRENT"] = 7] = "REOPEN_CURRENT";
    SymbolSwapMode[SymbolSwapMode["DISABLED"] = 8] = "DISABLED";
})(SymbolSwapMode = exports.SymbolSwapMode || (exports.SymbolSwapMode = {}));
